using System;
using System.Collections;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;

namespace Nicekit.Excel
{ 
  /// <summary>
  /// Common dialog for transfer data from DataGridView to MsExcel
  /// </summary>
  /// <example>
  /// private void mSOfficeToolStripMenuItem_Click(object sender, EventArgs e)
  /// {  //toMSOffice
  ///   FormGridToMSOffice.toMsOffice(
  ///     mSOfficeToolStripMenuItem.Text,
  ///     dataGridViewMain);
  /// }
  /// </example>
  public partial class FormGridToMSOffice : Form
  {

    public bool Converted = false;
    public DataGridView Grid = null;
 
    /// <summary>
    /// main function
    /// </summary>
    /// <param name="theCaption">caption</param>
    /// <param name="theGrid">grid with data</param>
    /// <returns></returns>
    public static bool toMsOffice(string theCaption,
      DataGridView theGrid)
    {
      if (theGrid == null)
        return false;
      using (FormGridToMSOffice f = new FormGridToMSOffice()) {
        f.Text = theCaption;
        f.Grid = theGrid;
        f.ShowDialog();
        return f.Converted;
      }
    }
    
    public FormGridToMSOffice()
    {
      InitializeComponent();
    }

    private void FormGridToMSOffice_Load(object sender, EventArgs e)
    { //Load
      checkedListBoxColumns.Items.Clear();
      foreach (DataGridViewColumn col in Grid.Columns) {
        checkedListBoxColumns.Items.Add(col.HeaderText, true);
      }
      progressBar1.Visible = false;
    }
    
    private void button1_Click(object sender, EventArgs e)
    { //Close;
      Close();
    }

    private void toExcelEvent(object sender, EventArgs e)
    {
      if (sender is System.Int32) {
        progressBar1.Value = (int)sender;
      }
    }
    
    private void buttonRun_Click(object sender, EventArgs e)
    {
      try {
        System.Windows.Forms.Cursor.Current = System.Windows.Forms.Cursors.WaitCursor;
        progressBar1.Maximum = Grid.RowCount-1;
        progressBar1.Visible = true;
        //--- checked columns
        ArrayList cols = new ArrayList();
        foreach (string s in checkedListBoxColumns.CheckedItems)
          cols.Add(s);
        //---
        Excel.dataGridViewToExcel(
          Grid, 
          1, 1,
          cols,
          new System.EventHandler(toExcelEvent));
        Converted = true;
      }
      finally {
        progressBar1.Visible = false;
        System.Windows.Forms.Cursor.Current = System.Windows.Forms.Cursors.Default;
      }
    }

    private void checkBox1_CheckedChanged(object sender, EventArgs e)
    { // check uncheck all columns
      for (int i = 0; i < checkedListBoxColumns.Items.Count; i++)
        checkedListBoxColumns.SetItemChecked(i, checkBox1.Checked);
    }


  }
}